SystemOrganization addCategory: #'Iliad-More-Examples'!

ILApplication subclass: #ILBlogApplication
	instanceVariableNames: 'postsWidgets'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Iliad-More-Examples'!

!ILBlogApplication class methodsFor: 'as yet unclassified' stamp: 'sa 4/23/2009 14:23'!
path
	^'/examples/blog'! !

!ILBlogApplication methodsFor: 'views-parts' stamp: 'sa 4/23/2009 14:33'!
actionsContents
	^[:e ||div |
		div := e div class: 'actions'; yourself.
		div anchor
			text: 'new post';
			action: [self addPost]]! !

!ILBlogApplication methodsFor: 'actions' stamp: 'sa 4/23/2009 14:32'!
addPost
	self show: ((ILBlogPost new asWidget addValidatedForm; yourself) addMessage: 'Add new post')
		onAnswer: [:ans | ans ifNotNil: [self model posts add: ans]]! !

!ILBlogApplication methodsFor: 'views' stamp: 'np 4/26/2009 14:24'!
index
	^[:e |
		e h1: 'Blog Example'.
		e build: self actionsContents.
		(self model posts asSortedCollection: [:a :b | a timestamp > b timestamp])
			do: [:each | e build: (self postContentsFor: each)]]! !

!ILBlogApplication methodsFor: 'initialization' stamp: 'sa 4/23/2009 14:26'!
initialize
	super initialize.
	model := ILBlogRepository default! !

!ILBlogApplication methodsFor: 'views' stamp: 'np 6/23/2009 16:09'!
post
	"View for a specific post"
	
	| post path |
	path := self route next.
	post := self model posts 
		detect: [:each | each title, each hash printString = path]
		ifNone: [self redirectToIndex].
	
	^self postContentsFor: post! !

!ILBlogApplication methodsFor: 'views-parts' stamp: 'np 6/22/2009 15:26'!
postContentsFor: aPost
	^[:e |
		e h2 anchor
			text: aPost title;
			action: [self redirectToLocal: 'post/', aPost title, aPost hash printString].
		e build: (self postWidgetFor: aPost)]! !

!ILBlogApplication methodsFor: 'accessing' stamp: 'np 4/24/2009 14:31'!
postWidgetFor: aPost
	^self postsWidgets at: aPost ifAbsentPut: [
		aPost asWidget 
			addValidatedSwitch; 
			yourself]! !

!ILBlogApplication methodsFor: 'accessing' stamp: 'np 4/24/2009 14:30'!
postsWidgets
	^postsWidgets ifNil: [postsWidgets := Dictionary new]! !

!ILBlogApplication methodsFor: 'building' stamp: 'np 7/12/2009 17:18'!
updatePage: aPage
	super updatePage: aPage.
	aPage head stylesheet href: '/stylesheets/iliad.css'! !

ILApplication subclass: #ILCounterApplication
	instanceVariableNames: 'counters'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Iliad-More-Examples'!

!ILCounterApplication class methodsFor: 'accessing' stamp: 'np 4/13/2009 14:01'!
path
	^'examples/counters'! !

!ILCounterApplication methodsFor: 'views' stamp: 'np 6/22/2009 15:25'!
counter
	^[:e |
		e build: self counters first]! !

!ILCounterApplication methodsFor: 'accessing' stamp: 'np 3/4/2009 15:32'!
counters
	^counters ifNil: [counters := {ILCounter new. ILCounter new. ILCounter new. ILCounter new}]! !

!ILCounterApplication methodsFor: 'views' stamp: 'np 3/4/2009 15:32'!
index
	^self counter! !

!ILCounterApplication methodsFor: 'views' stamp: 'np 6/22/2009 15:25'!
multicounter
	^[:e | 
		self counters do: [:each |
			e build: each]]! !

!ILCounterApplication methodsFor: 'building' stamp: 'np 7/12/2009 17:19'!
updatePage: aPage
	super updatePage: aPage.
	aPage head stylesheet href: '/stylesheets/iliad.css'! !

ILApplication subclass: #ILTodoListApplication
	instanceVariableNames: 'todoListWidget'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Iliad-More-Examples'!

!ILTodoListApplication class methodsFor: 'accessing' stamp: 'np 4/13/2009 14:01'!
path
	^'examples/todo'! !

!ILTodoListApplication methodsFor: 'views' stamp: 'np 4/13/2009 16:03'!
all
	self todoListWidget selectBlock: [:item | true].
	
	^self mainContents! !

!ILTodoListApplication methodsFor: 'views' stamp: 'np 4/13/2009 16:03'!
completed
	self todoListWidget selectBlock: [:item | item completed].
	
	^self mainContents! !

!ILTodoListApplication methodsFor: 'views' stamp: 'np 4/11/2009 17:57'!
index
	^self all! !

!ILTodoListApplication methodsFor: 'initialize-release' stamp: 'np 7/13/2009 14:41'!
initialize
	super initialize.
	self model: ILTodoListItemRepository default! !

!ILTodoListApplication methodsFor: 'views-parts' stamp: 'np 6/22/2009 15:26'!
mainContents
	^[:e | 
		e h1: 'Todo list'.
		e build: self selectionContents.
		e build: self todoListWidget]! !

!ILTodoListApplication methodsFor: 'views' stamp: 'np 4/13/2009 16:03'!
pending
	self todoListWidget selectBlock: [:item | item completed not].
	
	^self mainContents! !

!ILTodoListApplication methodsFor: 'views-parts' stamp: 'np 4/13/2009 16:03'!
selectionContents
	^[:e || div |
		div := e div class: 'selection'; yourself.
		#('all' 'completed' 'pending')
			do: [:each |
				div anchor
					action: [self redirectToLocal: each];
					text: each]
			separatedBy: [div space].
		e break]! !

!ILTodoListApplication methodsFor: 'accessing' stamp: 'np 7/13/2009 14:41'!
todoListWidget
	^todoListWidget ifNil: [todoListWidget := ILTodoListWidget new]! !

!ILTodoListApplication methodsFor: 'building' stamp: 'np 7/12/2009 19:09'!
updatePage: aPage
	super updatePage: aPage.
	aPage head stylesheet href: '/stylesheets/iliad.css'.
	aPage head javascript source: '/javascripts/lightbox.js'.
	aPage head stylesheet href: '/stylesheets/lightbox.css'.! !

Object subclass: #ILBlogPost
	instanceVariableNames: 'title body comments timestamp'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Iliad-More-Examples'!

!ILBlogPost class methodsFor: 'as yet unclassified' stamp: 'np 4/23/2009 14:49'!
descriptionBody
	^MAMemoDescription new
		priority: 3;
		autoAccessor: #body;
		label: 'Body';
		beRequired;
		yourself! !

!ILBlogPost class methodsFor: 'as yet unclassified' stamp: 'sa 4/23/2009 14:30'!
descriptionTimestamp
	^MATimeStampDescription new
		priority: 2;
		autoAccessor: #timestamp;
		label: 'Publication date';
		beRequired;
		yourself! !

!ILBlogPost class methodsFor: 'as yet unclassified' stamp: 'sa 4/23/2009 14:29'!
descriptionTitle
	^MAStringDescription new
		priority: 1;
		autoAccessor: #title;
		label: 'Title';
		beRequired;
		yourself! !

!ILBlogPost methodsFor: 'accessing' stamp: 'sa 4/23/2009 14:14'!
body
	^body! !

!ILBlogPost methodsFor: 'accessing' stamp: 'sa 4/23/2009 14:14'!
body: aString
	body := aString! !

!ILBlogPost methodsFor: 'initialization' stamp: 'sa 4/23/2009 14:13'!
initialize
	super initialize.
	title := ''.
	body := ''.
	comments := OrderedCollection new.
	timestamp := TimeStamp now! !

!ILBlogPost methodsFor: 'accessing-generated' stamp: 'sa 4/23/2009 14:38'!
timestamp
	^ timestamp! !

!ILBlogPost methodsFor: 'accessing-generated' stamp: 'np 4/23/2009 14:43'!
timestamp: anObject
	timestamp := anObject! !

!ILBlogPost methodsFor: 'accessing' stamp: 'sa 4/23/2009 14:14'!
title
	^title! !

!ILBlogPost methodsFor: 'accessing' stamp: 'sa 4/23/2009 14:13'!
title: aString
	title := aString! !

Object subclass: #ILBlogRepository
	instanceVariableNames: 'posts'
	classVariableNames: 'Default'
	poolDictionaries: ''
	category: 'Iliad-More-Examples'!

!ILBlogRepository class methodsFor: 'defaults' stamp: 'sa 4/23/2009 14:25'!
default
	^Default ifNil: [Default := self new]! !

!ILBlogRepository methodsFor: 'accessing' stamp: 'np 4/24/2009 15:01'!
posts
	^posts ifNil: [posts := OrderedCollection new]! !

Object subclass: #ILTodoListItem
	instanceVariableNames: 'deadline title description completed'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Iliad-More-Examples'!

!ILTodoListItem methodsFor: 'accessing' stamp: 'np 4/11/2009 17:54'!
completed
	^completed ifNil: [false]! !

!ILTodoListItem methodsFor: 'accessing' stamp: 'np 4/11/2009 17:55'!
completed: aBoolean
	completed := aBoolean! !

!ILTodoListItem methodsFor: 'accessing' stamp: 'np 4/11/2009 19:15'!
deadline
	^deadline ifNil: [deadline := Date tomorrow]! !

!ILTodoListItem methodsFor: 'accessing' stamp: 'np 4/11/2009 19:15'!
deadline: aDeadline
	deadline := aDeadline! !

!ILTodoListItem methodsFor: 'accessing' stamp: 'np 4/12/2009 15:32'!
description
	^description ifNil: ['']! !

!ILTodoListItem methodsFor: 'accessing' stamp: 'np 4/11/2009 17:54'!
description: aString
	description := aString! !

!ILTodoListItem methodsFor: 'accessing' stamp: 'np 4/12/2009 15:34'!
title
	^title ifNil: ['']! !

!ILTodoListItem methodsFor: 'accessing' stamp: 'np 4/11/2009 17:53'!
title: aString
	title := aString! !

Object subclass: #ILTodoListItemRepository
	instanceVariableNames: 'items'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Iliad-More-Examples'!

ILTodoListItemRepository class
	instanceVariableNames: 'default'!

ILTodoListItemRepository class
	instanceVariableNames: 'default'!

!ILTodoListItemRepository class methodsFor: 'as yet unclassified' stamp: 'np 4/12/2009 20:47'!
default
	^default ifNil: [default := self new]! !

!ILTodoListItemRepository methodsFor: 'message list' stamp: 'np 4/12/2009 20:48'!
addItem: anItem 
	self items add: anItem! !

!ILTodoListItemRepository methodsFor: 'accessing' stamp: 'np 4/12/2009 20:49'!
items
	^items ifNil: [items := OrderedCollection new]! !

!ILTodoListItemRepository methodsFor: 'actions' stamp: 'np 4/12/2009 20:48'!
removeItem: anItem
	self items remove: anItem! !

ILWidget subclass: #ILCounter
	instanceVariableNames: 'count'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Iliad-More-Examples'!

!ILCounter methodsFor: 'building' stamp: 'np 4/12/2009 20:57'!
contents
	^[:e |
		e h2: count asString.
		e anchor action: [self increase]; text: '++'.
		e space.
		e anchor action: [self decrease]; text: '--']! !

!ILCounter methodsFor: 'actions' stamp: 'np 4/11/2009 13:17'!
decrease
	count := count - 1.
	self markDirty! !

!ILCounter methodsFor: 'actions' stamp: 'np 4/11/2009 13:18'!
increase
	count := count + 1.
	self markDirty! !

!ILCounter methodsFor: 'initialize-release' stamp: 'np 10/27/2008 22:47'!
initialize
	super initialize.
	count := 0! !

ILWidget subclass: #ILTodoListItemEditor
	instanceVariableNames: 'item'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Iliad-More-Examples'!

!ILTodoListItemEditor methodsFor: 'building' stamp: 'np 4/13/2009 16:01'!
completedContents
	^[:e | 
		e tableData text: 'Completed'.
		e tableData checkbox
			action: [:val | self setItemCompleted: val];
			checked: self item completed]! !

!ILTodoListItemEditor methodsFor: 'building' stamp: 'np 4/13/2009 16:02'!
contents
	^[:e || div |
		div := e div class: 'edit'; yourself.
		div h2: 'Edit item'.
		div build: self editFormContents]! !

!ILTodoListItemEditor methodsFor: 'building' stamp: 'np 4/13/2009 16:01'!
deadlineContents
	^[:e |
		e tableData text: 'Deadline'.
		e tableData anchor
			action: [self setItemDeadline];
			text: self item deadline asString]! !

!ILTodoListItemEditor methodsFor: 'building' stamp: 'np 4/13/2009 16:02'!
descriptionContents
	^[:e |
		e tableData text: 'Decription'.
		e tableData textArea 
			text: self item description;
			columns: 40;
			rows: 4;
			action: [:val | self setItemDescription: val]]! !

!ILTodoListItemEditor methodsFor: 'building' stamp: 'np 4/13/2009 16:02'!
editFormContents
	^[:e || form tbody |
		form := e form.
		tbody := form table tableBody.
		tbody tableRow build: self deadlineContents.
		tbody tableRow build: self titleContents.
		tbody tableRow build: self descriptionContents.
		tbody tableRow build: self completedContents.
		form button 
			action: [self saveItem];
			text: 'save']! !

!ILTodoListItemEditor methodsFor: 'accessing' stamp: 'np 4/11/2009 18:22'!
item
	^item! !

!ILTodoListItemEditor methodsFor: 'accessing' stamp: 'np 4/11/2009 18:22'!
item: anItem 
	item := anItem! !

!ILTodoListItemEditor methodsFor: 'actions' stamp: 'np 4/11/2009 18:33'!
saveItem
	self answer: self item! !

!ILTodoListItemEditor methodsFor: 'actions' stamp: 'np 4/12/2009 14:59'!
setItemCompleted: aBoolean
	self item completed: aBoolean! !

!ILTodoListItemEditor methodsFor: 'actions' stamp: 'np 7/5/2009 18:57'!
setItemDeadline
	self
		show: ILCalendar new
		onAnswer: [:date | self item deadline: date]! !

!ILTodoListItemEditor methodsFor: 'actions' stamp: 'np 4/12/2009 14:59'!
setItemDescription: aString
	self item description: aString! !

!ILTodoListItemEditor methodsFor: 'actions' stamp: 'np 4/12/2009 14:59'!
setItemTitle: aString
	self item title: aString! !

!ILTodoListItemEditor methodsFor: 'building' stamp: 'np 4/13/2009 16:02'!
titleContents
	^[:e |
		e tableData text: 'Title'.
		e tableData input 
			value: self item title;
			size: 30;
			action: [:val | self setItemTitle: val]]! !

ILWidget subclass: #ILTodoListWidget
	instanceVariableNames: 'selectBlock'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Iliad-More-Examples'!

!ILTodoListWidget methodsFor: 'actions' stamp: 'np 7/13/2009 14:41'!
addNewItem
	| newItem |
	newItem := ILTodoListItem new.
	self 
		lightbox: (ILTodoListItemEditor new
			item: newItem;
			yourself)
		onAnswer: [:item | item ifNotNil: [
			self application model addItem: item]]
		! !

!ILTodoListWidget methodsFor: 'building' stamp: 'np 4/13/2009 16:03'!
contents
	^[:e || table | 
		table := e table.
		table build: self tableHeadContents.
		(self items asSortedCollection: [:a :b | a deadline < b deadline]) do: [:each |
			table build: (self rowContentsForItem: each)]. 
		e div anchor
			action: [self addNewItem];
			text: 'new']! !

!ILTodoListWidget methodsFor: 'actions' stamp: 'np 7/13/2009 14:41'!
editItem: anItem
	self lightbox: (ILTodoListItemEditor new 
		item: anItem; 
		yourself)! !

!ILTodoListWidget methodsFor: 'accessing' stamp: 'np 4/12/2009 20:49'!
items
	^self application model items select: self selectBlock! !

!ILTodoListWidget methodsFor: 'actions' stamp: 'np 4/12/2009 20:50'!
removeItem: anItem
	self application model removeItem: anItem.
	self markDirty! !

!ILTodoListWidget methodsFor: 'building' stamp: 'np 4/13/2009 16:02'!
rowContentsForItem: anItem
	^[:e || row |
		row := e tableRow.
		row tableData form checkbox
			checked: anItem completed;
			beSubmitOnClick;
			action: [:val | self setItem: anItem completed: val].
		row tableData text: anItem title.
		row tableData text: anItem description.
		row tableData text: anItem deadline asString.
		row tableData anchor
			action: [self editItem: anItem];
			text: 'edit'.
		row tableData anchor
			action: [self removeItem: anItem];
			text: 'remove'.] ! !

!ILTodoListWidget methodsFor: 'accessing' stamp: 'np 4/12/2009 16:27'!
selectBlock
	^selectBlock ifNil: [selectBlock := [:each |]]! !

!ILTodoListWidget methodsFor: 'accessing' stamp: 'np 4/12/2009 16:27'!
selectBlock: aBlock
	selectBlock := aBlock! !

!ILTodoListWidget methodsFor: 'actions' stamp: 'np 4/12/2009 15:35'!
setItem: anItem completed: aBoolean
	anItem completed: aBoolean.
	self markDirty! !

!ILTodoListWidget methodsFor: 'building' stamp: 'np 4/13/2009 16:03'!
tableHeadContents
	^[:e || head |
		head := e tableHead.
		head tableData text: ''.
		head tableData text: 'Title'.
		head tableData text: 'Description'.
		head tableData text: 'Deadline']! !
